betty.ancestry.media_type module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.media_type module

Data types that have media types.

class betty.ancestry.media_type.HasMediaType

  Bases: `LinkedDataDumpableJsonLdObject`

  A resource with an IANA media type.

  __init__(*args: Any, media_type: MediaType | None = None, **kwargs: Any)
  async dump_linked_data(project: Project) → DumpMapping[Dump]

    Dump this instance to JSON-LD.

  async classmethod linked_data_schema(project: Project) → JsonLdObject

    Define the JSON Schema for `betty.json.linked_data.LinkedDataDumpable.dump_linked_data()`.